NLSL: tensym.f90 File Reference

NLSL

- Main Page
- Modules
- Data Types List
- Files

- File List
- File Members

Functions/Subroutines
tensym.f90 File Reference

Go to the source code of this file.

## Functions/Subroutines
subroutine | tocart (t, iflg)
subroutine | tosphr (t, iflg)
subroutine | toaxil (t, iflg)
logical function | tcheck (ix, ix2, ident, lumsg)
logical function | symmsg (lu, ident, jx, form)
logical function | isaxial (t, iflg)
logical function | isrhomb (t, iflg)
logical function | isisotr (t, iflg)

## Function/Subroutine Documentation

logical function isaxial | ( | double precision, dimension(3) | t,
|  | integer | iflg
| ) |  |

Definition at line 265 of file tensym.f90.

logical function isisotr | ( | double precision, dimension(3) | t,
|  | integer | iflg
| ) |  |

Definition at line 302 of file tensym.f90.

logical function isrhomb | ( | double precision, dimension(3) | t,
|  | integer | iflg
| ) |  |

Definition at line 282 of file tensym.f90.

logical function symmsg | ( | integer | lu,
|  | character | ident,
|  | integer | jx,
|  | character | form
| ) |  |

Definition at line 239 of file tensym.f90.

logical function tcheck | ( | integer | ix,
|  | integer | ix2,
|  | character | ident,
|  | integer | lumsg
| ) |  |

Definition at line 138 of file tensym.f90.

subroutine toaxil | ( | double precision, dimension(3) | t,
|  | integer | iflg
| ) |  |

Definition at line 94 of file tensym.f90.

Here is the call graph for this function:

Here is the caller graph for this function:

subroutine tocart | ( | double precision, dimension(3) | t,
|  | integer | iflg
| ) |  |

Definition at line 40 of file tensym.f90.

Here is the caller graph for this function:

subroutine tosphr | ( | double precision, dimension(3) | t,
|  | integer | iflg
| ) |  |

Definition at line 66 of file tensym.f90.

Here is the caller graph for this function: